==> pochy-0.1.7-src.tar.gz: pochy-0.1.7-src/Template.cpp <==
// Template.cpp: CTemplate NX̃Cve[V
//
//////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "pochy.h"
#include "Template.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

//////////////////////////////////////////////////////////////////////
// \z/
//////////////////////////////////////////////////////////////////////

CTemplate::CTemplate()
{

}

CTemplate::~CTemplate()
{

}

void CTemplate::SetCurrentBody(CString body)
{
	m_body = body;
}

/*
%d	t
%f	ol
%N	ol̎
%F	ol̖O
%I	ol̃CjV
%s	
%t	
%c	Cc
%n	j[XO[v

%r	reply-to
%m	x-mailer

%M	bZ[W{
%Q	ptbZ[W{
%m	bZ[W{iȂj
%q	ptbZ[W{iȂj
%%	%
*/

CString CTemplate::GetString(CMimeDecode *md, CString tmpl)
{
	CString buf;

	for(int i=0; i<tmpl.GetLength(); i++){
		if(tmpl[i] == '%' && (i+1) < tmpl.GetLength()){
			switch(tmpl[i+1]){
			case 'd':
				buf += md->m_hi.GetDate();
				i++;
				continue;
			case 'f':
				buf += md->m_hi.GetFrom();
				i++;
				continue;
			case 's':
				buf += md->m_hi.GetSubject();
				i++;
				continue;
			case 't':
				buf += md->m_hi.GetTo();
				i++;
				continue;
			case 'c':
				buf += md->m_hi.GetCc();
				i++;
				continue;
			case 'r':
				buf += md->m_hi.GetReplyTo();
				i++;
				continue;
			case 'm':
				buf += md->m_hi.GetXmailer();
				i++;
				continue;
			case 'M':
				i++;
				continue;
			case 'Q':
				i++;
				continue;
			case '%':
				buf += "%";
				i++;
				continue;
			default:
				i++;
				continue;
			}
		}
		buf += tmpl[i];
	}
	return buf;
}

==> pochy-0.1.8-src.tar.gz: pochy-0.1.8-src/Template.cpp <==
// Template.cpp: CTemplate NX̃Cve[V
//
//////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "pochy.h"
#include "Template.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

//////////////////////////////////////////////////////////////////////
// \z/
//////////////////////////////////////////////////////////////////////

CTemplate::CTemplate()
{

}

CTemplate::~CTemplate()
{

}

void CTemplate::SetCurrentBody(CString body)
{
	m_body = body;
}

/*
%d	t
%f	ol
%N	ol̎
%F	ol̖O
%I	ol̃CjV
%s	
%t	
%c	Cc
%n	j[XO[v

%r	reply-to
%m	x-mailer

%M	bZ[W{
%Q	ptbZ[W{
%m	bZ[W{iȂj
%q	ptbZ[W{iȂj
%%	%
*/

CString CTemplate::GetString(CMimeDecode *md, CString tmpl)
{
	CString buf;

	for(int i=0; i<tmpl.GetLength(); i++){
		if(tmpl[i] == '%' && (i+1) < tmpl.GetLength()){
			switch(tmpl[i+1]){
			case 'd':
				if(md->m_hi.GetDate().IsEmpty()){
					buf += "none";
				}else{
					buf += md->m_hi.GetDate();
				}
				i++;
				continue;
			case 'f':
				if(md->m_hi.GetFrom().IsEmpty()){
					buf += "none";
				}else{
					buf += md->m_hi.GetFrom();
				}
				i++;
				continue;
			case 's':
				if(md->m_hi.GetSubject().IsEmpty()){
					buf += "none";
				}else{
					buf += md->m_hi.GetSubject();
				}
				i++;
				continue;
			case 't':
				if(md->m_hi.GetTo().IsEmpty()){
					buf += "none";
				}else{
					buf += md->m_hi.GetTo();
				}
				i++;
				continue;
			case 'c':
				if(md->m_hi.GetCc().IsEmpty()){
					buf += "none";
				}else{
					buf += md->m_hi.GetCc();
				}
				i++;
				continue;
			case 'r':
				if(md->m_hi.GetReplyTo().IsEmpty()){
					buf += "none";
				}else{
					buf += md->m_hi.GetReplyTo();
				}
				i++;
				continue;
			case 'm':
				if(md->m_hi.GetXmailer().IsEmpty()){
					buf += "none";
				}else{
					buf += md->m_hi.GetXmailer();
				}
				i++;
				continue;
			case 'M':
				i++;
				continue;
			case 'Q':
				i++;
				continue;
			case '%':
				buf += "%";
				i++;
				continue;
			default:
				i++;
				continue;
			}
		}
		buf += tmpl[i];
	}
	return buf;
}
